﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using Newtonsoft.Json;
using System.IO;

namespace Bird_tool
{
    public class AppConfig
    {
        public bool enable_local_server { get; set; } = true;
        public string api_address { get; set; } = "hofuniot.cn";
        public int web_port = 8080;
        public string wifi_ssid { get; set; } = "hf_test";
        public string wifi_passwd { get; set; } = "12345678";
    }

    public static class ConfigManager
    {
        private static readonly string ConfigPath =
            Path.Combine(Environment.CurrentDirectory, "config.json");

        public static AppConfig LoadConfig()
        {
            if (!File.Exists(ConfigPath))
            {
                var defaultConfig = new AppConfig();
                SaveConfig(defaultConfig);
                return defaultConfig;
            }

            //string json = File.ReadAllText(ConfigPath);
            
            try
            {
                using (var streamReader = new StreamReader(ConfigPath))
                using (var jsonReader = new JsonTextReader(streamReader))
                {
                    var serializer = new JsonSerializer();
                    return serializer.Deserialize<AppConfig>(jsonReader);
                }
            }
            catch (JsonException ex)
            {
                Console.WriteLine($"配置文件加载失败: {ex.Message}");
                // 处理损坏的配置文件
                File.Delete(ConfigPath);
                return new AppConfig();
            }
            catch (IOException ex)
            {
                Console.WriteLine($"文件访问错误: {ex.Message}");
                return new AppConfig();
            }
        }

        public static void SaveConfig(AppConfig config)
        {
            try
            {
                // 确保目录存在
                Directory.CreateDirectory(Path.GetDirectoryName(ConfigPath));

                // 使用临时文件写入，然后替换原文件，避免占用问题
                string tempFile = Path.GetTempFileName();
                string json = JsonConvert.SerializeObject(config, Formatting.Indented);
                File.WriteAllText(tempFile, json);

                // 替换原文件
                File.Copy(tempFile, ConfigPath, true);
                File.Delete(tempFile);
            }
            catch (Exception ex)
            {
                Console.WriteLine($"保存配置失败: {ex.Message}");
            }
        }
    }
}
